pub unsafe extern "C" fn SetModuleLoadHook(
rt: *mut JSRuntime,
func: ModuleLoadHook,
)Expand description
Set the HostLoadImportedModule hook for the runtime to the given function.
pub unsafe extern "C" fn SetModuleLoadHook(
rt: *mut JSRuntime,
func: ModuleLoadHook,
)Set the HostLoadImportedModule hook for the runtime to the given function.